@@ -69,7 +69,7 @@ S60ImageCaptureDecoder::~S60ImageCaptureDecoder()
 {
     if (m_imageDecoder) {
         delete m_imageDecoder;
-        m_imageDecoder = 0;
+        m_imageDecoder = NULL;
     }
 }
 
@@ -79,7 +79,7 @@ S60ImageCaptureDecoder *S60ImageCaptureDecoder::FileNewL(S60ImageCaptureSession
 {
     S60ImageCaptureDecoder* self = new (ELeave) S60ImageCaptureDecoder(imageSession,
                                                                        fileSystemAccess,
-                                                                       0,
+                                                                       NULL,
                                                                        fileName);
     CleanupStack::PushL(self);
     self->ConstructL(true);
@@ -94,7 +94,7 @@ S60ImageCaptureDecoder *S60ImageCaptureDecoder::DataNewL(S60ImageCaptureSession
     S60ImageCaptureDecoder* self = new (ELeave) S60ImageCaptureDecoder(imageSession,
                                                                        fileSystemAccess,
                                                                        data,
-                                                                       0);
+                                                                       NULL);
     CleanupStack::PushL(self);
     self->ConstructL(false);
     CleanupStack::Pop(self);
@@ -131,7 +131,7 @@ TFrameInfo *S60ImageCaptureDecoder::frameInfo()
         return &m_frameInfo;
     }
     else
-        return 0;
+        return NULL;
 }
 
 void S60ImageCaptureDecoder::RunL()
@@ -170,11 +170,11 @@ S60ImageCaptureEncoder::~S60ImageCaptureEncoder()
 {
     if (m_frameImageData) {
         delete m_frameImageData;
-        m_frameImageData = 0;
+        m_frameImageData = NULL;
     }
     if (m_imageEncoder) {
         delete m_imageEncoder;
-        m_imageEncoder = 0;
+        m_imageEncoder = NULL;
     }
 }
 
@@ -252,14 +252,14 @@ TInt S60ImageCaptureEncoder::RunError(TInt aError)
 
 S60ImageCaptureSession::S60ImageCaptureSession(QObject *parent) :
     QObject(parent),
-    m_cameraEngine(0),
-    m_advancedSettings(0),
-    m_cameraInfo(0),
-    m_previewBitmap(0),
-    m_activeScheduler(0),
-    m_fileSystemAccess(0),
-    m_imageDecoder(0),
-    m_imageEncoder(0),
+    m_cameraEngine(NULL),
+    m_advancedSettings(NULL),
+    m_cameraInfo(NULL),
+    m_previewBitmap(NULL),
+    m_activeScheduler(NULL),
+    m_fileSystemAccess(NULL),
+    m_imageDecoder(NULL),
+    m_imageEncoder(NULL),
     m_error(KErrNone),
     m_activeDeviceIndex(KDefaultCameraDevice),
     m_cameraStarted(false),
@@ -298,24 +298,24 @@ S60ImageCaptureSession::~S60ImageCaptureSession()
     if (m_imageDecoder) {
         m_imageDecoder->Cancel();
         delete m_imageDecoder;
-        m_imageDecoder = 0;
+        m_imageDecoder = NULL;
     }
     if (m_imageEncoder) {
         m_imageEncoder->Cancel();
         delete m_imageEncoder;
-        m_imageEncoder = 0;
+        m_imageEncoder = NULL;
     }
 
     if (m_previewBitmap) {
         delete m_previewBitmap;
-        m_previewBitmap = 0;
+        m_previewBitmap = NULL;
     }
 
     // Uninstall ActiveScheduler if needed
     if (m_activeScheduler) {
-        CActiveScheduler::Install(0);
+        CActiveScheduler::Install(NULL);
         delete m_activeScheduler;
-        m_activeScheduler = 0;
+        m_activeScheduler = NULL;
     }
 }
 
@@ -346,7 +346,7 @@ void S60ImageCaptureSession::deleteAdvancedSettings()
 {
     if (m_advancedSettings) {
         delete m_advancedSettings;
-        m_advancedSettings = 0;
+        m_advancedSettings = NULL;
         emit advancedSettingChanged();
     }
 }
@@ -390,14 +390,14 @@ void S60ImageCaptureSession::resetSession(bool errorHandling)
     int err = KErrNone;
     m_advancedSettings = S60CameraSettings::New(err, this, m_cameraEngine);
     if (err == KErrNotSupported) {
-        m_advancedSettings = 0;
+        m_advancedSettings = NULL;
 #ifndef S60_31_PLATFORM // Post S60 3.1 Platform
         // Adv. settings may not be supported for other than the Primary Camera
         if (m_cameraEngine->CurrentCameraIndex() == 0)
             setError(err, tr("Unexpected camera error."));
 #endif // !S60_31_PLATFORM
     } else if (err != KErrNone) { // Other errors
-        m_advancedSettings = 0;
+        m_advancedSettings = NULL;
         qWarning("Failed to create camera settings handler.");
         if (errorHandling)
             emit cameraError(QCamera::ServiceMissingError, tr("Failed to recover from error."));
@@ -651,12 +651,12 @@ void S60ImageCaptureSession::processFileName(const QString &fileName)
             fullFileName = KDefaultImagePath;
             if (fileName.at(0) != '\\')
                 fullFileName.append("\\");
-            fullFileName.append(QDir::toNativeSeparators(QDir::cleanPath(fileName)));
+            fullFileName.append(QDir::toNativeSeparators(fileName));
 
         // Absolute FileName
         } else {
             // Extract file name and path from the given location
-            fullFileName = QDir::toNativeSeparators(QDir::cleanPath(fileName));
+            fullFileName = QDir::toNativeSeparators(fileName);
         }
 
         QString fileNameOnly = fullFileName.right(fullFileName.length() - fullFileName.lastIndexOf("\\") - 1);
@@ -730,21 +730,21 @@ void S60ImageCaptureSession::MceoCapturedBitmapReady(CFbsBitmap* aBitmap)
         // Delete old instances if needed
         if (m_imageDecoder) {
             delete m_imageDecoder;
-            m_imageDecoder = 0;
+            m_imageDecoder = NULL;
         }
         if (m_previewBitmap) {
             delete m_previewBitmap;
-            m_previewBitmap = 0;
+            m_previewBitmap = NULL;
         }
 #endif // ECAM_CAMERA_API
         if (m_imageEncoder) {
             delete m_imageEncoder;
-            m_imageEncoder = 0;
+            m_imageEncoder = NULL;
         }
         if (m_fileSystemAccess) {
             m_fileSystemAccess->Close();
             delete m_fileSystemAccess;
-            m_fileSystemAccess = 0;
+            m_fileSystemAccess = NULL;
         }
 
         TInt saveError = KErrNone;
@@ -804,7 +804,7 @@ TFileName S60ImageCaptureSession::convertImagePath()
  */
 void S60ImageCaptureSession::saveImageL(TDesC8 *aData, TFileName &aPath)
 {
-    if (aData == 0)
+    if (aData == NULL)
         setError(KErrGeneral, tr("Captured image data is not available."), true);
 
     if (aPath.Size() > 0) {
@@ -817,17 +817,17 @@ void S60ImageCaptureSession::saveImageL(TDesC8 *aData, TFileName &aPath)
         // Delete old instances if needed
         if (m_imageDecoder) {
             delete m_imageDecoder;
-            m_imageDecoder = 0;
+            m_imageDecoder = NULL;
         }
         if (m_previewBitmap) {
             delete m_previewBitmap;
-            m_previewBitmap = 0;
+            m_previewBitmap = NULL;
         }
 #endif // ECAM_PREVIEW_API
         if (m_fileSystemAccess) {
             m_fileSystemAccess->Close();
             delete m_fileSystemAccess;
-            m_fileSystemAccess = 0;
+            m_fileSystemAccess = NULL;
         }
 
         RFs *fileSystemAccess = new (ELeave) RFs;
@@ -988,11 +988,9 @@ QList<QSize> S60ImageCaptureSession::supportedCaptureSizesForCodec(const QString
 
         CCamera *camera = m_cameraEngine->Camera();
         TSize imageSize;
-        if (camera) {
-            for (int i = 0; i < m_cameraInfo->iNumImageSizesSupported; i++) {
-                camera->EnumerateCaptureSizes(imageSize, i, format);
-                list << QSize(imageSize.iWidth, imageSize.iHeight); // Add resolution to the list
-            }
+        for (int i = 0; i < m_cameraInfo->iNumImageSizesSupported; i++) {
+            camera->EnumerateCaptureSizes(imageSize, i, format);
+            list << QSize(imageSize.iWidth, imageSize.iHeight); // Add resolution to the list
         }
     }
 
@@ -1341,7 +1339,7 @@ void S60ImageCaptureSession::setFlashMode(QCameraExposure::FlashModes mode)
 
 void S60ImageCaptureSession::doSetFlashModeL(QCameraExposure::FlashModes mode)
 {
-    if (m_cameraEngine && m_cameraEngine->Camera()) {
+    if (m_cameraEngine) {
         CCamera *camera = m_cameraEngine->Camera();
         switch(mode) {
             case QCameraExposure::FlashOff:
@@ -1364,14 +1362,14 @@ void S60ImageCaptureSession::doSetFlashModeL(QCameraExposure::FlashModes mode)
                 setError(KErrNotSupported, tr("Requested flash mode is not suported"));
                 break;
         }
-    } else {
-        setError(KErrNotReady, tr("Unexpected camera error."));
     }
+    else
+        setError(KErrNotReady, tr("Unexpected camera error."));
 }
 
 QCameraExposure::FlashMode S60ImageCaptureSession::flashMode()
 {
-    if (m_cameraEngine && m_cameraEngine->Camera()) {
+    if (m_cameraEngine) {
         CCamera *camera = m_cameraEngine->Camera();
         switch(camera->Flash()) {
             case CCamera::EFlashAuto:
@@ -1388,9 +1386,9 @@ QCameraExposure::FlashMode S60ImageCaptureSession::flashMode()
             default:
                 return QCameraExposure::FlashAuto; // Most probable default
         }
-    } else {
-        setError(KErrNotReady, tr("Unexpected camera error."));
     }
+    else
+        setError(KErrNotReady, tr("Unexpected camera error."));
 
     return QCameraExposure::FlashOff;
 }
@@ -1422,7 +1420,7 @@ QCameraExposure::FlashModes S60ImageCaptureSession::supportedFlashModes()
 
 QCameraExposure::ExposureMode S60ImageCaptureSession::exposureMode()
 {
-    if (m_cameraEngine && m_cameraEngine->Camera()) {
+    if (m_cameraEngine) {
         CCamera* camera = m_cameraEngine->Camera();
         switch(camera->Exposure()) {
             case CCamera::EExposureManual:
@@ -1505,7 +1503,7 @@ void S60ImageCaptureSession::setExposureMode(QCameraExposure::ExposureMode mode)
 
 void S60ImageCaptureSession::doSetExposureModeL( QCameraExposure::ExposureMode mode)
 {
-    if (m_cameraEngine && m_cameraEngine->Camera()) {
+    if (m_cameraEngine) {
         CCamera *camera = m_cameraEngine->Camera();
         switch(mode) {
             case QCameraExposure::ExposureManual:
@@ -1538,14 +1536,14 @@ void S60ImageCaptureSession::doSetExposureModeL( QCameraExposure::ExposureMode m
                 setError(KErrNotSupported, tr("Requested exposure mode is not suported"));
                 break;
         }
-    } else {
-        setError(KErrNotReady, tr("Unexpected camera error."));
     }
+    else
+        setError(KErrNotReady, tr("Unexpected camera error."));
 }
 
 int S60ImageCaptureSession::contrast() const
 {
-    if (m_cameraEngine && m_cameraEngine->Camera()) {
+    if (m_cameraEngine) {
         return m_cameraEngine->Camera()->Contrast();
     } else {
         return 0;
@@ -1554,17 +1552,17 @@ int S60ImageCaptureSession::contrast() const
 
 void S60ImageCaptureSession::setContrast(int value)
 {
-    if (m_cameraEngine && m_cameraEngine->Camera()) {
+    if (m_cameraEngine) {
         TRAPD(err, m_cameraEngine->Camera()->SetContrastL(value));
         setError(err, tr("Failed to set contrast."));
-    } else {
-        setError(KErrNotReady, tr("Unexpected camera error."));
     }
+    else
+        setError(KErrNotReady, tr("Unexpected camera error."));
 }
 
 int S60ImageCaptureSession::brightness() const
 {
-    if (m_cameraEngine && m_cameraEngine->Camera()) {
+    if (m_cameraEngine) {
         return m_cameraEngine->Camera()->Brightness();
     } else {
         return 0;
@@ -1573,17 +1571,17 @@ int S60ImageCaptureSession::brightness() const
 
 void S60ImageCaptureSession::setBrightness(int value)
 {
-    if (m_cameraEngine && m_cameraEngine->Camera()) {
+    if (m_cameraEngine) {
         TRAPD(err, m_cameraEngine->Camera()->SetBrightnessL(value));
         setError(err, tr("Failed to set brightness."));
-    } else {
-        setError(KErrNotReady, tr("Unexpected camera error."));
     }
+    else
+        setError(KErrNotReady, tr("Unexpected camera error."));
 }
 
  QCameraImageProcessing::WhiteBalanceMode S60ImageCaptureSession::whiteBalanceMode()
 {
-    if (m_cameraEngine && m_cameraEngine->Camera()) {
+    if (m_cameraEngine) {
         CCamera::TWhiteBalance mode = m_cameraEngine->Camera()->WhiteBalance();
         switch(mode) {
             case CCamera::EWBAuto:
@@ -1621,7 +1619,7 @@ void S60ImageCaptureSession::setWhiteBalanceMode( QCameraImageProcessing::WhiteB
 
 void S60ImageCaptureSession::doSetWhiteBalanceModeL( QCameraImageProcessing::WhiteBalanceMode mode)
 {
-    if (m_cameraEngine && m_cameraEngine->Camera()) {
+    if (m_cameraEngine) {
         CCamera* camera = m_cameraEngine->Camera();
         switch(mode) {
             case  QCameraImageProcessing::WhiteBalanceAuto:
@@ -1656,9 +1654,9 @@ void S60ImageCaptureSession::doSetWhiteBalanceModeL( QCameraImageProcessing::Whi
                 setError(KErrNotSupported, tr("Requested white balance mode is not suported"));
                 break;
         }
-    } else {
-        setError(KErrNotReady, tr("Unexpected camera error."));
     }
+    else
+        setError(KErrNotReady, tr("Unexpected camera error."));
 }
 
 bool S60ImageCaptureSession::isWhiteBalanceModeSupported(QCameraImageProcessing::WhiteBalanceMode mode) const
@@ -1757,12 +1755,12 @@ void S60ImageCaptureSession::handleImageDecoded(int error)
     // Delete unneeded objects
     if (m_imageDecoder) {
         delete m_imageDecoder;
-        m_imageDecoder = 0;
+        m_imageDecoder = NULL;
     }
     if (m_fileSystemAccess) {
         m_fileSystemAccess->Close();
         delete m_fileSystemAccess;
-        m_fileSystemAccess = 0;
+        m_fileSystemAccess = NULL;
     }
 
     // Check status of decoding
@@ -1770,7 +1768,7 @@ void S60ImageCaptureSession::handleImageDecoded(int error)
         if (m_previewBitmap) {
             m_previewBitmap->Reset();
             delete m_previewBitmap;
-            m_previewBitmap = 0;
+            m_previewBitmap = NULL;
         }
         releaseImageBuffer();
         if (m_previewInWaitLoop) {
@@ -1789,7 +1787,7 @@ void S60ImageCaptureSession::handleImageDecoded(int error)
     if (m_previewBitmap) {
         m_previewBitmap->Reset();
         delete m_previewBitmap;
-        m_previewBitmap = 0;
+        m_previewBitmap = NULL;
     }
 
     QT_TRYCATCH_LEAVING( emit imageCaptured(m_currentImageId, preview) );
@@ -1820,7 +1818,7 @@ void S60ImageCaptureSession::handleImageEncoded(int error)
 
     if (m_imageEncoder) {
         delete m_imageEncoder;
-        m_imageEncoder = 0;
+        m_imageEncoder = NULL;
     }
 
 #ifndef ECAM_PREVIEW_API
