@@ -42,26 +42,15 @@
 #include "qgeomapdata.h"
 #include "qgeomapdata_p.h"
 
-#include <QGraphicsScene>
-#include <QGraphicsItem>
-#include <QGraphicsPolygonItem>
-#include <QGraphicsLineItem>
-#include <QGraphicsEllipseItem>
-#include <QGraphicsPathItem>
-
 #include "qgeoboundingbox.h"
 #include "qgeocoordinate.h"
 #include "qgraphicsgeomap.h"
 #include "qgeomapobject.h"
-#include "qgeomappixmapobject.h"
 #include "qgeomapgroupobject.h"
-#include "qgeomaptextobject.h"
 #include "qgeomappingmanagerengine.h"
 #include "qgeomapoverlay.h"
 
-#include "qgeomapobjectengine_p.h"
 #include "qgeomapobject_p.h"
-#include "projwrapper_p.h"
 
 QTM_BEGIN_NAMESPACE
 
@@ -73,7 +62,6 @@ QTM_BEGIN_NAMESPACE
 
 
     \inmodule QtLocation
-    \since 1.1
 
     \ingroup maps-impl
 
@@ -122,12 +110,11 @@ QGeoMapData::~QGeoMapData()
 }
 
 /*!
-    This function is run after the QGeoMapData instance has been
+    This function is run after the QGeoMapData instance has been 
     constructed.
 
     Any subclasses which override this function should make sure that
-    QGeoMapData::init() is called within the body of the overriding function.
-    \since 1.1
+    QGeoMapData::init() is called within the body of the overridding function.
 */
 void QGeoMapData::init()
 {
@@ -137,7 +124,6 @@ void QGeoMapData::init()
 
 /*!
     Returns the mapping engine that this map data object is associated with.
-    \since 1.1
 */
 QGeoMappingManagerEngine* QGeoMapData::engine() const
 {
@@ -147,7 +133,6 @@ QGeoMappingManagerEngine* QGeoMapData::engine() const
 /*!
     Returns the QGeoMapObject which acts as the parent to all QGeoMapObject
     instances which are added to the map by the user.
-    \since 1.1
 */
 QGeoMapObject* QGeoMapData::containerObject()
 {
@@ -158,7 +143,6 @@ QGeoMapObject* QGeoMapData::containerObject()
     Sets the size of the map viewport to \a size.
 
     The size will be adjusted by the associated QGraphicsGeoMap as it resizes.
-    \since 1.1
 */
 void QGeoMapData::setWindowSize(const QSizeF &size)
 {
@@ -176,7 +160,6 @@ void QGeoMapData::setWindowSize(const QSizeF &size)
     Returns the size of the map viewport.
 
     The size will be adjusted by the associated QGraphicsGeoMap as it resizes.
-    \since 1.1
 */
 QSizeF QGeoMapData::windowSize() const
 {
@@ -192,7 +175,6 @@ QSizeF QGeoMapData::windowSize() const
     If \a zoomLevel is less than minimumZoomLevel() then minimumZoomLevel()
     will be used, and if \a zoomLevel is  larger than
     maximumZoomLevel() then maximumZoomLevel() will be used.
-    \since 1.1
 */
 void QGeoMapData::setZoomLevel(qreal zoomLevel)
 {
@@ -215,137 +197,12 @@ void QGeoMapData::setZoomLevel(qreal zoomLevel)
 
     Larger values of the zoom level correspond to more detailed views of the
     map.
-    \since 1.1
 */
 qreal QGeoMapData::zoomLevel() const
 {
     return d_ptr->zoomLevel;
 }
 
-/*!
-    \property QGeoMapData::supportsBearing
-
-    Returns whether bearing is supported by this engine.
-    \since 1.2
-*/
-bool QGeoMapData::supportsBearing() const
-{
-    return d_ptr->engine->supportsBearing();
-}
-
-/*!
-    Sets the bearing of the map to \a bearing.
-
-    Value in degrees in the range of 0-360. 0 being equivalent to 0 degrees from
-    north.
-    \since 1.2
-*/
-void QGeoMapData::setBearing(qreal bearing)
-{
-    if (!supportsBearing())
-        return;
-
-    bearing = qMin(bearing, qreal(360.0));
-    bearing = qMax(bearing, qreal(0.0));
-
-    if (d_ptr->bearing == bearing)
-        return;
-
-    d_ptr->bearing = bearing;
-
-    if (!d_ptr->blockPropertyChangeSignals)
-        emit bearingChanged(d_ptr->bearing);
-}
-
-/*!
-    \property QGeoMapData::bearing
-
-    Returns the current bearing of the map.
-
-    Value in degrees in the range of 0-360. 0 being equivalent to 0 degrees from
-    north.
-    \since 1.2
-*/
-qreal QGeoMapData::bearing() const
-{
-    return d_ptr->bearing;
-}
-
-/*!
-    \property QGeoMapData::supportsTilting
-
-    Returns whether tilting is supported by this engine.
-    \since 1.2
-*/
-bool QGeoMapData::supportsTilting() const
-{
-    return d_ptr->engine->supportsTilting();
-}
-
-/*!
-    \property QGeoMapData::minimumTilt
-
-    Returns minimum tilt supported by this engine.
-    \since 1.2
-*/
-qreal QGeoMapData::minimumTilt() const
-{
-    return d_ptr->engine->minimumTilt();
-}
-
-/*!
-    \property QGeoMapData::maximumTilt
-
-    Returns maximum tilt supported by this engine.
-    \since 1.2
-*/
-qreal QGeoMapData::maximumTilt() const
-{
-    return d_ptr->engine->maximumTilt();
-}
-
-/*!
-    Sets the tilt of the map to \a tilt.
-
-    Value in degrees where 0 is equivalent to 90 degrees between view and earth's
-    surface i.e. looking straight down to earth.
-
-    If \a tilt is less than minimumTilt() then minimumTilt()
-    will be used, and if \a tilt is  larger than
-    maximumTilt() then maximumTilt() will be used.
-    \since 1.2
-*/
-void QGeoMapData::setTilt(qreal tilt)
-{
-    if (!supportsTilting())
-        return;
-
-    tilt = qMin(tilt, d_ptr->engine->maximumTilt());
-    tilt = qMax(tilt, d_ptr->engine->minimumTilt());
-
-    if (d_ptr->tilt == tilt)
-        return;
-
-    d_ptr->tilt = tilt;
-
-    if (!d_ptr->blockPropertyChangeSignals)
-        emit tiltChanged(d_ptr->tilt);
-}
-
-/*!
-    \property QGeoMapData::tilt
-
-    Returns the current tilt of the map.
-
-    Value in degrees where 0 is equivalent to 90 degrees between view and earth's
-    surface i.e. looking straight down to earth.
-    \since 1.2
-*/
-qreal QGeoMapData::tilt() const
-{
-    return d_ptr->tilt;
-}
-
 /*!
     Pans the map view \a dx pixels in the x direction and \a dy pixels
     in the y direction.
@@ -356,7 +213,6 @@ qreal QGeoMapData::tilt() const
     viewed area down.
 
     Subclasses should call QGeoMapData::setCenter() when the pan has completed.
-    \since 1.1
 */
 void QGeoMapData::pan(int dx, int dy)
 {
@@ -366,7 +222,6 @@ void QGeoMapData::pan(int dx, int dy)
 
 /*!
     Centers the map viewport on the coordinate \a center.
-    \since 1.1
 */
 void QGeoMapData::setCenter(const QGeoCoordinate &center)
 {
@@ -383,7 +238,6 @@ void QGeoMapData::setCenter(const QGeoCoordinate &center)
     \property QGeoMapData::center
 
     Returns the coordinate of the point in the center of the map viewport.
-    \since 1.1
 */
 QGeoCoordinate QGeoMapData::center() const
 {
@@ -392,7 +246,6 @@ QGeoCoordinate QGeoMapData::center() const
 
 /*!
     Changes the type of map data to display to \a mapType.
-    \since 1.1
 */
 void QGeoMapData::setMapType(QGraphicsGeoMap::MapType mapType)
 {
@@ -409,7 +262,6 @@ void QGeoMapData::setMapType(QGraphicsGeoMap::MapType mapType)
     \property QGeoMapData::mapType
 
     Returns the type of map data which is being displayed.
-    \since 1.1
 */
 QGraphicsGeoMap::MapType QGeoMapData::mapType() const
 {
@@ -418,7 +270,6 @@ QGraphicsGeoMap::MapType QGeoMapData::mapType() const
 
 /*!
     Changes the connectivity mode of this map to \a connectivityMode
-    \since 1.1
 */
 void QGeoMapData::setConnectivityMode(QGraphicsGeoMap::ConnectivityMode connectivityMode)
 {
@@ -435,7 +286,6 @@ void QGeoMapData::setConnectivityMode(QGraphicsGeoMap::ConnectivityMode connecti
     \property QGeoMapData::connectivityMode
 
     Returns the connectivity mode for this map.
-    \since 1.1
 */
 QGraphicsGeoMap::ConnectivityMode QGeoMapData::connectivityMode() const
 {
@@ -444,7 +294,6 @@ QGraphicsGeoMap::ConnectivityMode QGeoMapData::connectivityMode() const
 
 /*!
     Returns the map objects associated with this map.
-    \since 1.1
 */
 QList<QGeoMapObject*> QGeoMapData::mapObjects() const
 {
@@ -459,32 +308,29 @@ QList<QGeoMapObject*> QGeoMapData::mapObjects() const
     in the order they were added.
 
     The map will take ownership of the \a mapObject.
-    \since 1.1
 */
 void QGeoMapData::addMapObject(QGeoMapObject *mapObject)
 {
-    d_ptr->addObject(mapObject);
+    d_ptr->containerObject->addChildObject(mapObject);
 }
 
 /*!
     Removes \a mapObject from the list of map objects managed by this map.
     The map will release ownership of the \a mapObject.
-    \since 1.1
 */
 void QGeoMapData::removeMapObject(QGeoMapObject *mapObject)
 {
-    d_ptr->removeObject(mapObject);
+    d_ptr->containerObject->removeChildObject(mapObject);
 }
 
 /*!
     Clears the map objects associated with this map.
 
     The map objects will be deleted.
-    \since 1.1
 */
 void QGeoMapData::clearMapObjects()
 {
-    d_ptr->clearObjects();
+    d_ptr->containerObject->clearChildObjects();
 }
 
 /*!
@@ -494,7 +340,6 @@ void QGeoMapData::clearMapObjects()
 
     The bounding box which is returned is defined by the upper left and
     lower right corners of the visible area of the map.
-    \since 1.1
 */
 
 /*!
@@ -508,13 +353,11 @@ void QGeoMapData::clearMapObjects()
     If \a preserveViewportCenter is false the map will be centered on the
     bounding box \a bounds before the zoom level is changed, otherwise the
     center of the map will not be changed.
-    \since 1.1
 */
 
 /*!
     Returns the list of visible map objects managed by this map which
     contain the point \a screenPosition within their boundaries.
-    \since 1.1
 */
 QList<QGeoMapObject*> QGeoMapData::mapObjectsAtScreenPosition(const QPointF &screenPosition) const
 {
@@ -534,7 +377,6 @@ QList<QGeoMapObject*> QGeoMapData::mapObjectsAtScreenPosition(const QPointF &scr
 /*!
     Returns the list of visible map objects managed by this map which are displayed at
     least partially within the on screen rectangle \a screenRect.
-    \since 1.1
 */
 QList<QGeoMapObject*> QGeoMapData::mapObjectsInScreenRect(const QRectF &screenRect) const
 {
@@ -558,14 +400,13 @@ QList<QGeoMapObject*> QGeoMapData::mapObjectsInScreenRect(const QRectF &screenRe
 /*!
     Returns the list of visible map objects manager by this widget which
     are displayed at least partially within the viewport of the map.
-    \since 1.1
 */
 QList<QGeoMapObject*> QGeoMapData::mapObjectsInViewport() const
 {
-    return this->mapObjectsInScreenRect(QRectF(0.0,
-                                               0.0,
-                                               d_ptr->windowSize.width(),
-                                               d_ptr->windowSize.height()));
+    return mapObjectsInScreenRect(QRectF(0.0,
+                                         0.0,
+                                         d_ptr->windowSize.width(),
+                                         d_ptr->windowSize.height()));
 }
 
 /*!
@@ -575,7 +416,6 @@ QList<QGeoMapObject*> QGeoMapData::mapObjectsInViewport() const
 
     An invalid QPointF will be returned if \a coordinate is invalid or is not
     within the current viewport.
-    \since 1.1
 */
 
 /*!
@@ -586,7 +426,6 @@ QList<QGeoMapObject*> QGeoMapData::mapObjectsInViewport() const
 
     An invalid QGeoCoordinate will be returned if \a screenPosition is invalid
     or is not within the current viewport.
-    \since 1.1
 */
 
 /*!
@@ -596,7 +435,6 @@ QList<QGeoMapObject*> QGeoMapData::mapObjectsInViewport() const
     This will paint the map with paintMap(), then the map overlays with
     QGeoMapOverlay::paint(), then the map objects with paintObjects(), and
     finally paintProviderNotices().
-    \since 1.1
 */
 void QGeoMapData::paint(QPainter *painter, const QStyleOptionGraphicsItem *option)
 {
@@ -618,7 +456,6 @@ void QGeoMapData::paint(QPainter *painter, const QStyleOptionGraphicsItem *optio
     in the paint() method.
 
     The default implementation does not paint anything.
-    \since 1.1
 */
 void QGeoMapData::paintMap(QPainter *painter, const QStyleOptionGraphicsItem *option)
 {
@@ -629,13 +466,7 @@ void QGeoMapData::paintMap(QPainter *painter, const QStyleOptionGraphicsItem *op
 /*!
     Paints the map objects on \a painter, using the options \a option.
 
-    The default implementation makes use of the coordinateToScreenPosition
-    implemented by the subclass to perform object positioning and rendering.
-
-    This implementation should suffice for most common use cases, and supports
-    the full range of coordinate systems and transforms available to a
-    QGeoMapObject.
-    \since 1.1
+    The default implementation does not paint anything.
 */
 void QGeoMapData::paintObjects(QPainter *painter, const QStyleOptionGraphicsItem *option)
 {
@@ -658,7 +489,6 @@ void QGeoMapData::paintObjects(QPainter *painter, const QStyleOptionGraphicsItem
     "mapping.notices.poweredby.alignment", with type Qt::Alignment.
 
     The default implementation does not paint anything.
-    \since 1.1
 */
 void QGeoMapData::paintProviderNotices(QPainter *painter, const QStyleOptionGraphicsItem *option)
 {
@@ -666,22 +496,8 @@ void QGeoMapData::paintProviderNotices(QPainter *painter, const QStyleOptionGrap
     Q_UNUSED(option)
 }
 
-/*!
-    Creates a QGeoMapObjectInfo instance which implements the behaviours o
-    the map object \a object which are specific to this QGeoMapData.
-
-    The default implementation returns 0.
-    \since 1.1
-*/
-QGeoMapObjectInfo *QGeoMapData::createMapObjectInfo(QGeoMapObject *object)
-{
-    Q_UNUSED(object);
-    return 0;
-}
-
 /*!
     Returns the map overlays associated with this map.
-    \since 1.1
 */
 QList<QGeoMapOverlay*> QGeoMapData::mapOverlays() const
 {
@@ -694,7 +510,6 @@ QList<QGeoMapOverlay*> QGeoMapData::mapOverlays() const
     The overlays will be drawn in the order in which they were added.
 
     The map will take ownership of \a overlay.
-    \since 1.1
 */
 void QGeoMapData::addMapOverlay(QGeoMapOverlay *overlay)
 {
@@ -709,7 +524,6 @@ void QGeoMapData::addMapOverlay(QGeoMapOverlay *overlay)
     Removes \a overlay from the list of map overlays associated with this map.
 
     The map will release ownership of \a overlay.
-    \since 1.1
 */
 void QGeoMapData::removeMapOverlay(QGeoMapOverlay *overlay)
 {
@@ -723,7 +537,6 @@ void QGeoMapData::removeMapOverlay(QGeoMapOverlay *overlay)
     Clears the map overlays associated with this map.
 
     The map overlays will be deleted.
-    \since 1.1
 */
 void QGeoMapData::clearMapOverlays()
 {
@@ -731,6 +544,17 @@ void QGeoMapData::clearMapOverlays()
     d_ptr->overlays.clear();
 }
 
+/*!
+    Creates a QGeoMapObjectInfo instance which implements the behaviours of
+    the map object \a object which are specific to this QGeoMapData.
+
+    The default implementation returns 0.
+*/
+QGeoMapObjectInfo* QGeoMapData::createMapObjectInfo(QGeoMapObject *object)
+{
+    Q_UNUSED(object)
+    return 0;
+}
 
 /*!
     Sets whether changes to properties will trigger their corresponding signals to \a block.
@@ -738,13 +562,12 @@ void QGeoMapData::clearMapOverlays()
     By default the QGeoMapData implementations of the property functions are used
     which cause the property notification signals to be emitted immediately.
 
-    Calling this function with \a block set to true will prevent these
+    Calling this function with \a block set to false will prevent these
     signals from being called, which will allow a subclass to defer the
     emission of the signal until a later time.
 
     If this function needs to be called it should be used as soon as possible,
     preferably in the constructor of the QGeoMapData subclass.
-    \since 1.1
 */
 void QGeoMapData::setBlockPropertyChangeSignals(bool block)
 {
@@ -754,11 +577,10 @@ void QGeoMapData::setBlockPropertyChangeSignals(bool block)
 /*!
 \fn void QGeoMapData::windowSizeChanged(const QSizeF &windowSize)
 
-    This signal is emitted when the size of the window which contains
+    This signal is emitted when the size of the window which contains 
     the map has changed.
 
     The new value is \a windowSize.
-    \since 1.1
 */
 
 /*!
@@ -767,25 +589,6 @@ void QGeoMapData::setBlockPropertyChangeSignals(bool block)
     This signal is emitted when the zoom level of the map has changed.
 
     The new value is \a zoomLevel.
-    \since 1.1
-*/
-
-/*!
-\fn void QGeoMapData::bearingChanged(qreal bearing)
-
-    This signal is emitted when the bearing of the map has changed.
-
-    The new value is \a bearing.
-    \since 1.2
-*/
-
-/*!
-\fn void QGeoMapData::tiltChanged(qreal tilt)
-
-    This signal is emitted when the tilt of the map has changed.
-
-    The new value is \a tilt.
-    \since 1.2
 */
 
 /*!
@@ -794,7 +597,6 @@ void QGeoMapData::setBlockPropertyChangeSignals(bool block)
     This signal is emitted when the center of the map has changed.
 
     The new value is \a coordinate.
-    \since 1.1
 */
 
 /*!
@@ -803,45 +605,36 @@ void QGeoMapData::setBlockPropertyChangeSignals(bool block)
     This signal is emitted when the type of the map has changes.
 
     The value is \a mapType.
-    \since 1.1
 */
 
 /*!
 \fn void QGeoMapData::connectivityModeChanged(QGraphicsGeoMap::ConnectivityMode connectivityMode)
 
-    This signal is emitted when the connectivity mode used to fetch the
+    This signal is emitted when the connectivity mode used to fetch the 
     map data has changed.
 
     The new value is \a connectivityMode.
-    \since 1.1
 */
 
 /*!
 \fn void QGeoMapData::updateMapDisplay(const QRectF &target)
 
-    This signal is emitted when the region \a target of the window which
+    This signal is emitted when the region \a target of the window which 
     contains the map needs to be updated.
 
 
     If \a target is empty then the entire map will be updated.
-    \since 1.1
 */
 
 /*******************************************************************************
 *******************************************************************************/
 
 QGeoMapDataPrivate::QGeoMapDataPrivate(QGeoMapData *parent, QGeoMappingManagerEngine *engine)
-    : QObject(0),
-      engine(engine),
+    : engine(engine),
       containerObject(0),
       zoomLevel(-1.0),
-      shiftSinceLastInval(0, 0),
-      windowSize(0, 0),
-      bearing(0.0),
-      tilt(0.0),
       blockPropertyChangeSignals(false),
-      q_ptr(parent)
-{}
+      q_ptr(parent) {}
 
 QGeoMapDataPrivate::~QGeoMapDataPrivate()
 {
@@ -850,38 +643,6 @@ QGeoMapDataPrivate::~QGeoMapDataPrivate()
     qDeleteAll(overlays);
 }
 
-void QGeoMapDataPrivate::addObject(QGeoMapObject *object)
-{
-    containerObject->addChildObject(object);
-    //emit q_ptr->updateMapDisplay();
-}
-
-void QGeoMapDataPrivate::removeObject(QGeoMapObject *object)
-{
-    containerObject->removeChildObject(object);
-}
-
-void QGeoMapDataPrivate::clearObjects()
-{
-    foreach (QGeoMapObject *obj, containerObject->childObjects()) {
-        this->removeObject(obj);
-        delete obj;
-    }
-}
-
-QPointF QGeoMapDataPrivate::coordinateToScreenPosition(double lon, double lat) const
-{
-    QGeoCoordinate c(lon, lat);
-    return q_ptr->coordinateToScreenPosition(c);
-}
-
-void QGeoMapDataPrivate::emitUpdateMapDisplay(const QRectF &target)
-{
-    emit q_ptr->updateMapDisplay(target);
-}
-
-
 #include "moc_qgeomapdata.cpp"
-#include "moc_qgeomapdata_p.cpp"
 
 QTM_END_NAMESPACE
