@@ -56,9 +56,7 @@
 #include <qmediaplaylistcontrol.h>
 #include <qmediaplaylistsourcecontrol.h>
 #include <qvideowidget.h>
-#include <qvideosurfaceoutput_p.h>
 #include <qgraphicsvideoitem.h>
-#include <qmedianetworkaccesscontrol.h>
 
 QT_BEGIN_NAMESPACE
 
@@ -67,9 +65,8 @@ QT_BEGIN_NAMESPACE
     \brief The QMediaPlayer class allows the playing of a media source.
     \inmodule QtMultimediaKit
     \ingroup multimedia
-    \since 1.0
-
 
+    
 
     The QMediaPlayer class is a high level media playback class. It can be used
     to playback such content as songs, movies and internet radio. The content
@@ -126,8 +123,6 @@ public:
 
     QPointer<QObject> videoOutput;
     QMediaPlaylist *playlist;
-    QMediaNetworkAccessControl *networkAccessControl;
-    QVideoSurfaceOutput surfaceOutput;
 
     void _q_stateChanged(QMediaPlayer::State state);
     void _q_mediaStatusChanged(QMediaPlayer::MediaStatus status);
@@ -252,9 +247,6 @@ static QMediaService *playerService(QMediaPlayer::Flags flags, QMediaServiceProv
         if (flags & QMediaPlayer::StreamPlayback)
             features |= QMediaServiceProviderHint::StreamPlayback;
 
-        if (flags & QMediaPlayer::VideoSurface)
-            features |= QMediaServiceProviderHint::VideoSurface;
-
         return provider->requestService(Q_MEDIASERVICE_MEDIAPLAYER,
                                         QMediaServiceProviderHint(features));
     } else
@@ -283,7 +275,7 @@ QMediaPlayer::QMediaPlayer(QObject *parent, QMediaPlayer::Flags flags, QMediaSer
     } else {
         d->control = qobject_cast<QMediaPlayerControl*>(d->service->requestControl(QMediaPlayerControl_iid));
         d->playlistSourceControl = qobject_cast<QMediaPlaylistSourceControl*>(d->service->requestControl(QMediaPlaylistSourceControl_iid));
-        d->networkAccessControl = qobject_cast<QMediaNetworkAccessControl*>(d->service->requestControl(QMediaNetworkAccessControl_iid));
+
         if (d->control != 0) {
             connect(d->control, SIGNAL(mediaChanged(QMediaContent)), SIGNAL(mediaChanged(QMediaContent)));
             connect(d->control, SIGNAL(stateChanged(QMediaPlayer::State)), SLOT(_q_stateChanged(QMediaPlayer::State)));
@@ -307,10 +299,6 @@ QMediaPlayer::QMediaPlayer(QObject *parent, QMediaPlayer::Flags flags, QMediaSer
             if (d->control->mediaStatus() == StalledMedia || d->control->mediaStatus() == BufferingMedia)
                 addPropertyWatch("bufferStatus");
         }
-        if (d->networkAccessControl != 0) {
-            connect(d->networkAccessControl, SIGNAL(configurationChanged(QNetworkConfiguration)),
-            this, SIGNAL(networkConfigurationChanged(QNetworkConfiguration)));
-        }
     }
 }
 
@@ -401,21 +389,6 @@ void QMediaPlayer::setPlaylist(QMediaPlaylist *playlist)
     }
 }
 
-/*!
-    Sets the network access points for remote media playback.
-    \a configurations contains, in ascending preferential order, a list of
-    configuration  that can be used for network access.
-
-    This will invalidate the choice of previous configurations.
-*/
-void QMediaPlayer::setNetworkConfigurations(const QList<QNetworkConfiguration> &configurations)
-{
-    Q_D(QMediaPlayer);
-
-    if (d->networkAccessControl)
-        d->networkAccessControl->setConfigurations(configurations);
-}
-
 QMediaPlayer::State QMediaPlayer::state() const
 {
     return d_func()->state;
@@ -535,22 +508,6 @@ QString QMediaPlayer::errorString() const
     return d_func()->errorString;
 }
 
-/*!
-    Returns the current network access point  in use.
-    If a default contructed QNetworkConfiguration is returned
-    this feature is not available or that none of the
-    current supplied configurations are in use.
-*/
-QNetworkConfiguration QMediaPlayer::currentNetworkConfiguration() const
-{
-    Q_D(const QMediaPlayer);
-
-    if (d->networkAccessControl)
-        return d_func()->networkAccessControl->currentConfiguration();
-
-    return QNetworkConfiguration();
-}
-
 //public Q_SLOTS:
 /*!
     Start or resume playing the current source.
@@ -749,27 +706,6 @@ void QMediaPlayer::setVideoOutput(QGraphicsVideoItem *output)
     d->videoOutput = output && bind(output) ? output : 0;
 }
 
-/*!
-    Sets a video \a surface as the video output of a media player.
-
-    If a video output has already been set on the media player the new surface
-    will replace it.
-*/
-
-void QMediaPlayer::setVideoOutput(QAbstractVideoSurface *surface)
-{
-    Q_D(QMediaPlayer);
-
-    d->surfaceOutput.setVideoSurface(surface);
-
-    if (d->videoOutput != &d->surfaceOutput) {
-        if (d->videoOutput)
-            unbind(d->videoOutput);
-
-        d->videoOutput = bind(&d->surfaceOutput) ? &d->surfaceOutput : 0;
-    }
-}
-
 // Enums
 /*!
     \enum QMediaPlayer::State
@@ -1058,25 +994,18 @@ void QMediaPlayer::setVideoOutput(QAbstractVideoSurface *surface)
     Signal the amount of the local buffer filled as a percentage by \a percentFilled.
 */
 
-/*!
-   \fn void QMediaPlayer::networkConfigurationChanged(const QNetworkConfiguration &configuration)
-
-    Signal that the active in use network access point  has been changed to \a configuration and all subsequent network access will use this \a configuration.
-*/
-
 /*!
     \enum QMediaPlayer::Flag
 
-    \value LowLatency       The player is expected to be used with simple audio formats,
+    \value LowLatency
+            The player is expected to be used with simple audio formats,
             but playback should start without significant delay.
             Such playback service can be used for beeps, ringtones, etc.
 
-    \value StreamPlayback   The player is expected to play QIODevice based streams.
+    \value StreamPlayback
+            The player is expected to play QIODevice based streams.
             If passed to QMediaPlayer constructor, the service supporting
             streams playback will be chosen.
-
-    \value VideoSurface     The player is expected to be able to render to a
-            QAbstractVideoSurface \l {setVideoOutput()}{output}.
 */
 
 #include "moc_qmediaplayer.cpp"
