@@ -75,13 +75,6 @@ QVideoWidgetControlBackend::QVideoWidgetControlBackend(
     QBoxLayout *layout = new QVBoxLayout;
     layout->setMargin(0);
     layout->setSpacing(0);
-
-#ifdef Q_OS_SYMBIAN
-    // On some cases the flag is not reset automatically
-    // This would lead to viewfinder not being visible on Symbian
-    control->videoWidget()->setAttribute(Qt::WA_WState_ExplicitShowHide, false);
-#endif // Q_OS_SYMBIAN
-
     layout->addWidget(control->videoWidget());
 
     widget->setLayout(layout);
@@ -585,15 +578,11 @@ void QVideoWidgetPrivate::_q_dimensionsChanged()
 
 /*!
     \class QVideoWidget
-
+    
 
     \brief The QVideoWidget class provides a widget which presents video
     produced by a media object.
     \ingroup multimedia
-    \inmodule QtMultimediaKit
-    \since 1.0
-
-    \inmodule QtMultimediaKit
 
     Attaching a QVideoWidget to a QMediaObject allows it to display the
     video or image output of that media object.  A QVideoWidget is attached
@@ -736,7 +725,7 @@ void QVideoWidget::setFullScreen(bool fullScreen)
         flags |= Qt::Window;
         flags &= ~Qt::SubWindow;
         setWindowFlags(flags);
-
+        
         showFullScreen();
     } else {
         showNormal();
